Slot: description - LinkML Model

# Slot: description

a description of the element's purpose and use

URI: linkml:description

## Domain and Range

Element → 0..1 String

## Parents

## Children

## Used by

- ClassDefinition
- CommonMetadata
- Definition
- Element
- EnumDefinition
- PermissibleValue
- SchemaDefinition
- SlotDefinition
- SubsetDefinition
- TypeDefinition

## Other properties

Mappings: |  | skos:definition
In Subsets: |  | owl